@@ -46,6 +46,7 @@ class Document(BaseAPIObject):
         "data",
         "description",
         "language",
+        "publish_at",
         "published_url",
         "related_article",
         "source",
@@ -218,13 +219,9 @@ class DocumentClient(BaseAPIClient):
     def search(self, query, **params):
         """Return documents matching a search query"""
 
+        # legacy parameter mentions renamed to hl
         mentions = params.pop("mentions", None)
-        if mentions is not None:  # pragma: no cover
-            warnings.warn(
-                "The `mentions` argument to `search` is deprecated, "
-                "it will always include mentions from all pages now",
-                DeprecationWarning,
-            )
+        params["hl"] = mentions
         data = params.pop("data", None)
         if data is not None:  # pragma: no cover
             warnings.warn(
@@ -272,6 +269,7 @@ class DocumentClient(BaseAPIClient):
             "language",
             "original_extension",
             "related_article",
+            "publish_at",
             "published_url",
             "source",
             "title",
